==> openjdk-src-15.0.1.u9-1-aarch64.pkg.tar.xz: jdk.jdeps/com/sun/tools/javap/resources/javap.java <==
package com.sun.tools.javap.resources;

public final class javap extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "err.bad.constant.pool", "error while reading constant pool for {0}: {1}" },
            { "err.bad.innerclasses.attribute", "bad InnerClasses attribute for {0}" },
            { "err.cant.find.module", "Cannot find module {0}" },
            { "err.cant.find.module.ex", "Problem finding module {0}: {1}" },
            { "err.class.not.found", "class not found: {0}" },
            { "err.crash", "A serious internal error has occurred: {0}\nPlease file a bug report, and include the following information:\n{1}" },
            { "err.end.of.file", "unexpected end of file while reading {0}" },
            { "err.file.not.found", "file not found: {0}" },
            { "err.incompatible.options", "bad combination of options: {0}" },
            { "err.internal.error", "internal error: {0} {1} {2}" },
            { "err.invalid.arg.for.option", "invalid argument for option: {0}" },
            { "err.invalid.use.of.option", "invalid use of option: {0}" },
            { "err.ioerror", "IO error reading {0}: {1}" },
            { "err.missing.arg", "no value given for {0}" },
            { "err.no.SourceFile.attribute", "no SourceFile attribute" },
            { "err.no.classes.specified", "no classes specified" },
            { "err.nomem", "Insufficient memory. To increase memory use -J-Xmx option." },
            { "err.not.standard.file.manager", "can only specify class files when using a standard file manager" },
            { "err.only.for.launcher", "This option can only be used when invoking javap from the command-line launcher." },
            { "err.prefix", "Error:" },
            { "err.source.file.not.found", "source file not found" },
            { "err.unknown.option", "unknown option: {0}" },
            { "main.opt.J", "  -J<vm-option>                    Specify a VM option" },
            { "main.opt.bootclasspath", "  -bootclasspath <path>            Override location of bootstrap class files" },
            { "main.opt.c", "  -c                               Disassemble the code" },
            { "main.opt.class_path", "  --class-path <path>              Specify where to find user class files" },
            { "main.opt.classpath", "  -classpath <path>                Specify where to find user class files" },
            { "main.opt.constants", "  -constants                       Show final constants" },
            { "main.opt.cp", "  -cp <path>                       Specify where to find user class files" },
            { "main.opt.help", "  --help -help -h -?               Print this help message" },
            { "main.opt.l", "  -l                               Print line number and local variable tables" },
            { "main.opt.module", "  --module <module>, -m <module>   Specify module containing classes to be disassembled" },
            { "main.opt.module_path", "  --module-path <path>             Specify where to find application modules" },
            { "main.opt.multi_release", "  --multi-release <version>        Specify the version to use in multi-release JAR files" },
            { "main.opt.p", "  -p  -private                     Show all classes and members" },
            { "main.opt.package", "  -package                         Show package/protected/public classes\n                                   and members (default)" },
            { "main.opt.protected", "  -protected                       Show protected/public classes and members" },
            { "main.opt.public", "  -public                          Show only public classes and members" },
            { "main.opt.s", "  -s                               Print internal type signatures" },
            { "main.opt.sysinfo", "  -sysinfo                         Show system info (path, size, date, SHA-256 hash)\n                                   of class being processed" },
            { "main.opt.system", "  --system <jdk>                   Specify where to find system modules" },
            { "main.opt.upgrade_module_path", "  --upgrade-module-path <path>     Specify where to find upgradeable modules" },
            { "main.opt.v", "  -v  -verbose                     Print additional information" },
            { "main.opt.version", "  -version                         Version information" },
            { "main.usage", "Usage: {0} <options> <classes>\nwhere possible options include:" },
            { "main.usage.foot", "\nGNU-style options may use '=' instead of whitespace to separate the name of an option\nfrom its value.\n\nEach class to be shown may be specified by a filename, a URL, or by its fully\nqualified class name. Examples:\n   path/to/MyClass.class\n   jar:file:///path/to/MyJar.jar!/mypkg/MyClass.class\n   java.lang.Object\n" },
            { "main.usage.summary", "Usage: {0} <options> <classes>\nuse --help for a list of possible options" },
            { "note.prefix", "Note:" },
            { "warn.prefix", "Warning:" },
            { "warn.unexpected.class", "File {0} does not contain class {1}" },
        };
    }
}

==> openjdk-src-24.0.2.u12-1-aarch64.pkg.tar.xz: jdk.jdeps/com/sun/tools/javap/resources/javap.java <==
package com.sun.tools.javap.resources;

public final class javap extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "err.bad.constant.pool", "error while reading constant pool for {0}: {1}" },
            { "err.bad.innerclasses.attribute", "bad InnerClasses attribute for {0}" },
            { "err.cant.find.module", "Cannot find module {0}" },
            { "err.cant.find.module.ex", "Problem finding module {0}: {1}" },
            { "err.class.not.found", "class not found: {0}" },
            { "err.crash", "A serious internal error has occurred: {0}\nPlease file a bug report, and include the following information:\n{1}" },
            { "err.end.of.file", "unexpected end of file while reading {0}" },
            { "err.fatal.err", "Fatal error: {0}" },
            { "err.file.not.found", "file not found: {0}" },
            { "err.incompatible.options", "bad combination of options: {0}" },
            { "err.internal.error", "internal error: {0} {1} {2}" },
            { "err.invalid.arg.for.option", "invalid argument for option: {0}" },
            { "err.invalid.use.of.option", "invalid use of option: {0}" },
            { "err.ioerror", "IO error reading {0}: {1}" },
            { "err.missing.arg", "no value given for {0}" },
            { "err.no.SourceFile.attribute", "no SourceFile attribute" },
            { "err.no.classes.specified", "no classes specified" },
            { "err.nomem", "Insufficient memory. To increase memory use -J-Xmx option." },
            { "err.not.standard.file.manager", "can only specify class files when using a standard file manager" },
            { "err.only.for.launcher", "This option can only be used when invoking javap from the command-line launcher." },
            { "err.prefix", "Error:" },
            { "err.source.file.not.found", "source file not found" },
            { "err.unknown.option", "unknown option: {0}" },
            { "javap.description", "disassemble one or more class files" },
            { "main.opt.J", "  -J<vm-option>                    Specify a VM option" },
            { "main.opt.bootclasspath", "  -bootclasspath <path>            Override location of bootstrap class files" },
            { "main.opt.c", "  -c                               Disassemble the code" },
            { "main.opt.class_path", "  --class-path <path>              Specify where to find user class files" },
            { "main.opt.classpath", "  -classpath <path>                Specify where to find user class files" },
            { "main.opt.constants", "  -constants                       Show final constants" },
            { "main.opt.cp", "  -cp <path>                       Specify where to find user class files" },
            { "main.opt.help", "  --help -help -h -?               Print this help message" },
            { "main.opt.l", "  -l                               Print line number and local variable tables, works in combination with -c" },
            { "main.opt.module", "  --module <module>  -m <module>   Specify module containing classes to be disassembled" },
            { "main.opt.module_path", "  --module-path <path>             Specify where to find application modules" },
            { "main.opt.multi_release", "  --multi-release <version>        Specify the version to use in multi-release JAR files" },
            { "main.opt.p", "  -p  -private                     Show all classes and members" },
            { "main.opt.package", "  -package                         Show package/protected/public classes\n                                   and members (default)" },
            { "main.opt.protected", "  -protected                       Show protected/public classes and members" },
            { "main.opt.public", "  -public                          Show only public classes and members" },
            { "main.opt.s", "  -s                               Print internal type signatures" },
            { "main.opt.sysinfo", "  -sysinfo                         Show system info (path, size, date, SHA-256 hash)\n                                   of class being processed" },
            { "main.opt.system", "  --system <jdk>                   Specify where to find system modules" },
            { "main.opt.upgrade_module_path", "  --upgrade-module-path <path>     Specify where to find upgradeable modules" },
            { "main.opt.v", "  -v  -verbose                     Print additional information" },
            { "main.opt.verify", "  -verify                          Print additional class verification info" },
            { "main.opt.version", "  -version                         Version information" },
            { "main.usage", "Usage: {0} <options> <classes>\nwhere possible options include:" },
            { "main.usage.foot", "\nGNU-style options may use '=' instead of whitespace to separate the name of an option\nfrom its value.\n\nEach class to be shown may be specified by a filename, a URL, or by its fully\nqualified class name. Examples:\n   path/to/MyClass.class\n   jar:file:///path/to/MyJar.jar!/mypkg/MyClass.class\n   java.lang.Object\n" },
            { "main.usage.summary", "Usage: {0} <options> <classes>\nuse --help for a list of possible options" },
            { "note.prefix", "Note:" },
            { "warn.prefix", "Warning:" },
            { "warn.unexpected.class", "File {0} does not contain class {1}" },
        };
    }
}
